pub struct WifiApConfigStatic {
pub ap_ssid: String<32>,
pub sta_ssid: String<32>,
pub ap_password: String<63>,
pub sta_password: String<63>,
pub channel: u8,
pub band: BandMode,
pub mac: [u8; 6],
}Expand description
WiFi access point configuration.
Contains settings for running the device as a WiFi access point.
Fields
ap_ssid: String<32>Wifi Mode - Access Point (ap) or Station (sta) Mode. Access Point by default. Network name (SSID), max 32 characters.
sta_ssid: String<32>ap_password: String<63>Mandatory WiFi password, max 63 characters.
We don’t want None here as it would present an open network,
which is not something we want to support.
sta_password: String<63>channel: u8WiFi channel (1-14 for 2.4GHz, 36+ for 5GHz).
band: BandModeWiFi band mode (2.4GHz / 5GHz / Auto). Ignored on chips without 5GHz.
mac: [u8; 6]MAC address for the access point interface.